@@ -5,6 +5,7 @@ from rich.prompt import Confirm
 
 from digicloud import schemas
 from .base import Lister, ShowOne, Command
+from ..cli import parseractions
 from ..error_handlers import CLIError
 from ..utils import is_tty
 
@@ -79,6 +80,7 @@ class CreateInstance(ShowOne):
         parser.add_argument(
             '--root-volume-size',
             required=False,
+            type=int,
             metavar='<root_volume_size>',
             help=('Optionally you can set the size of root volume, otherwise root volume '
                   'will be created according to the instance type')
@@ -148,11 +150,13 @@ class CreateInstance(ShowOne):
         )
 
         parser.add_argument(
-            '--additional-volumes',
-            metavar='<additional_volumes>',
+            '--additional-volume',
+            metavar='size=<size>,type=<type>',
+            dest='additional_volumes',
+            action=parseractions.MultiKeyValueAction,
+            required_keys=['size', 'type'],
             default=[],
-            action='append',
-            help='attach additional volume automatically, e.g --additional-volumes 500'
+            help='Create and attach additional volume automatically, e.g --additional-volume size=500,type=SSD'
         )
 
         parser.add_argument(
@@ -167,12 +171,14 @@ class CreateInstance(ShowOne):
             metavar='<count>',
             type=int,
             help='Create multiple instance at once',
+            default=1,
             required=False
         )
 
         return parser
 
     def _check_arg_validity(self, parsed_args):
+        min_windows_root_vol_size = 20
         rules = [
             (
                 all((parsed_args.advanced, parsed_args.simple)),
@@ -200,18 +206,20 @@ class CreateInstance(ShowOne):
             ),
             # Creating multiple instance conditions:
             (
-                parsed_args.with_public_ip and parsed_args.count is not None,
+                parsed_args.with_public_ip and parsed_args.count > 1,
                 "--with-public-ip and --count must not be used together",
             ),
             (
-                parsed_args.public_ip and parsed_args.count is not None,
+                parsed_args.public_ip and parsed_args.count > 1,
                 "--public-ip and --count must not be used together",
             ),
             (
-                parsed_args.additional_volumes and parsed_args.count is not None,
-                "using --additional-volumes and --count together is not supported",
+                any([
+                    str(volume['type']).upper() not in ('SSD', 'ULTRA_DISK')
+                    for volume in parsed_args.additional_volumes
+                ]),
+                "additional volume type must be either 'SSD' or 'ULTRA_DISK'"
             ),
-
             (
                 parsed_args.image and parsed_args.snapshot,
                 "--image and --snapshot must not be used together",
@@ -220,6 +228,17 @@ class CreateInstance(ShowOne):
                 parsed_args.image is None and parsed_args.snapshot is None,
                 "one of the --image and --snapshot arguments must be used",
             ),
+            (
+                parsed_args.count and parsed_args.count <= 0,
+                "--count must be greater than 0",
+            ),
+            (
+                parsed_args.image.lower().startswith('windows') 
+                    and parsed_args.root_volume_size 
+                    and parsed_args.root_volume_size is not None
+                    and parsed_args.root_volume_size < min_windows_root_vol_size,
+                "Minimum required root volume size for Windows images is 20 Gigabytes"
+            ),
 
         ]
         errors = []
@@ -252,9 +271,9 @@ class CreateInstance(ShowOne):
         if parsed_args.additional_volumes:
             payload['additional_volumes'] = [
                 {
-                    "size": volume_size,
-                    "volume_type": "SSD",
-                } for volume_size in parsed_args.additional_volumes
+                    "size": additional_volume['size'],
+                    "volume_type": additional_volume['type'],
+                } for additional_volume in parsed_args.additional_volumes
             ]
         if parsed_args.with_public_ip:
             payload['has_public_ip'] = parsed_args.with_public_ip
@@ -298,6 +317,13 @@ class CreateInstance(ShowOne):
             payload['template']['root_volume_type'] = parsed_args.root_volume_type
         if parsed_args.root_volume_size:
             payload['template']['root_volume_size'] = parsed_args.root_volume_size
+        if parsed_args.additional_volumes:
+            payload['template']['additional_volumes'] = [
+                {
+                    "size": additional_volume['size'],
+                    "volume_type": additional_volume['type'],
+                } for additional_volume in parsed_args.additional_volumes
+            ]
 
         data = self.app.session.post('/instance-groups', payload)
         command = "[bold blue]digicloud instance list --id %s[/bold blue]" % " ".join(
@@ -336,10 +362,12 @@ class DeleteInstance(Command):
             metavar='<instance>',
             help='Instance name or ID',
         )
+
         parser.add_argument(
             '--delete-volumes',
-            metavar='<instance>',
-            help='Instance name or ID',
+            help='Delete additional volumes attached to instance',
+            default=None,
+            action='store_true'
         )
 
         parser.add_argument(
@@ -359,13 +387,34 @@ class DeleteInstance(Command):
         return parser
 
     def take_action(self, parsed_args):
+        snapshot_check_uri = '/instances/%s/snapshots' % parsed_args.instance
+        instance_snapshot = self.app.session.get(snapshot_check_uri)
+        if instance_snapshot:
+            self.app.stdout.write(
+                "NOTE: You have snapshot on this instance so you can't delete its volumes\n"
+            )
+            return
+
         if not self.confirm_instance_deletion(parsed_args):
             return
         uri = '/instances/%s' % parsed_args.instance
-        if self.confirm_volume_deletion(parsed_args):
-            uri += "?delete_root_volume=true"
+
+        additional_volumes_ids = self._get_additional_volumes_ids(parsed_args.instance)
+        if self.confirm_root_volume_deletion(parsed_args):
+            uri += self._format_query_param(uri, "delete_root_volume=true")
+        if additional_volumes_ids and self.confirm_additional_volume_deletion(parsed_args):
+            uri += self._format_query_param(uri, "delete_additional_volumes=true")
+
         self.app.session.delete(uri)
 
+    def _has_query_param(self, uri: str):
+        return '?' in uri
+
+    def _format_query_param(self, uri, new_query_param: str):
+        new_query_param = new_query_param.strip()
+        return f"&{new_query_param}" if self._has_query_param(uri) else f"?{new_query_param}"
+
+
     def confirm_instance_deletion(self, parsed_args):
         if parsed_args.i_am_sure:
             return True
@@ -386,16 +435,32 @@ class DeleteInstance(Command):
                 " without '--i-am-sure' switch\n")
             return False
 
-    def confirm_volume_deletion(self, parsed_args):
-        if parsed_args.delete_root_volume:
+    def confirm_root_volume_deletion(self, parsed_args):
+        return self._volume_deletion_confirmation(
+                parsed_args.delete_root_volume,
+                "Would you like to also delete the root volume of this instance?"
+        )
+
+    def confirm_additional_volume_deletion(self, parsed_args):
+        return self._volume_deletion_confirmation(
+                parsed_args.delete_volumes,
+                "Would you like to also delete the additional volumes attached to this instance?"
+        )
+
+    def _volume_deletion_confirmation(self, already_confirmed, msg):
+        if already_confirmed:
             return True
         if is_tty():
             return Confirm.ask(
-                "Would you like to also delete the root volume of this instance?",
+                msg,
                 default=False
             )
         return False
 
+    def _get_additional_volumes_ids(self, instance_name):
+        uri = '/instances/%s/volumes' % instance_name
+        non_root_volumes_id = [vol['id'] for vol in self.app.session.get(uri) if vol['is_root'] == False]
+        return non_root_volumes_id
 
 class ListInstanceVolume(Lister):
     """List instance volume(s)."""
@@ -521,7 +586,7 @@ class DetachInstanceVolume(Command):
 
 class ListInstanceInterface(Lister):
     """List instance interface(s)."""
-    schema = schemas.InstanceInterface(many=True)
+    schema = schemas.ListInstanceInterface(many=True)
 
     def get_parser(self, prog_name):
         parser = super(ListInstanceInterface, self).get_parser(prog_name)
