@@ -1,15 +1,13 @@
 """
     DigiCloud InstanceTypes Service.
 """
-from cliff.lister import Lister
-from cliff.show import ShowOne
-
-from .. import formatter
-from ..utils import tabulate
+from digicloud import schemas
+from .base import Lister, ShowOne
 
 
 class ListInstanceType(Lister):
     """List instance-types."""
+    schema = schemas.InstanceType(many=True)
 
     def get_parser(self, prog_name):
         parser = super(ListInstanceType, self).get_parser(prog_name)
@@ -20,20 +18,29 @@ class ListInstanceType(Lister):
         )
         return parser
 
-    def take_action(self, parsed_args):
+    def get_data(self, parsed_args):
         uri = '/instance-types'
         if parsed_args.family:
             uri = '/instance-types?family=%s' % parsed_args.family
-        data = self.app.session.get(uri)
+        data = self._sort_instance_types(self.app.session.get(uri))
+        return data
 
-        for instance in data:
-            instance['ram'] = formatter.format_ram(instance['ram'])
-
-        return tabulate(data)
+    def _sort_instance_types(self, instance_types):
+        return sorted(
+            instance_types,
+            key=lambda item: (
+                # Sorting keys
+                item.get('family'),
+                item.get('vcpus'),
+                item.get('ram'),
+            ),
+            reverse=True
+        )
 
 
 class ShowInstanceType(ShowOne):
     """Show instance-type details."""
+    schema = schemas.InstanceType()
 
     def get_parser(self, prog_name):
         parser = super(ShowInstanceType, self).get_parser(prog_name)
@@ -44,10 +51,7 @@ class ShowInstanceType(ShowOne):
         )
         return parser
 
-    def take_action(self, parsed_args):
+    def get_data(self, parsed_args):
         uri = f'/instance-types/{parsed_args.instance_type}'
         data = self.app.session.get(uri)
-
-        data['ram'] = formatter.format_ram(data['ram'])
-
-        return tabulate(data)
+        return data
