@@ -559,6 +559,8 @@ class EdgeDomainList(Schema):
     name = fields.Str()
     status = fields.Str()
     record_count = fields.Integer()
+    is_subdomain = fields.Boolean()
+    ns_verification = fields.Str()
 
     class Meta:
         ordered = True
@@ -567,6 +569,8 @@ class EdgeDomainList(Schema):
 class EdgeDomainDetails(Schema):
     id = fields.Str()
     name = fields.Str()
+    is_subdomain = fields.Boolean()
+    ns_verification = fields.Str()
 
     class Meta:
         ordered = True
@@ -580,13 +584,6 @@ class DomainDNSSECDetails(Schema):
         ordered = True
 
 
-class DomainNSRecordsDetails(Schema):
-    digicloud_ns_records = fields.List(fields.Str())
-
-    class Meta:
-        ordered = True
-
-
 class RecordListSchema(Schema):
     available_keys = ("id", "name", "ttl", "note", "type", "ip_address", "proxy", "content", "port", "weight", "proto",
                       "service", "target", "priority", "mail_server",)
@@ -766,8 +763,7 @@ class LocationDetails(Schema):
     id = fields.Str()
     name = fields.Str()
     path = fields.Str()
-    path_type = fields.Str()
-    path_extensions = fields.List(fields.Str())
+    path_case_sensitive = fields.Bool()
     upstream_id = fields.Str()
     origin_headers = fields.List(fields.Dict())
     response_headers = fields.List(fields.Dict())
@@ -777,8 +773,28 @@ class LocationDetails(Schema):
     cache_key = fields.Str()
     cache_cookie_name = fields.Str()
     cache_zone = fields.Str()
+    secure_link_enable = fields.Bool()
+    secure_link_secret = fields.Str()
+    redirect_enable = fields.Bool()
+    redirect_url = fields.Str()
+    redirect_status_code = fields.Integer()
     rate_limit_id = fields.Str()
 
+    @post_dump
+    def convert_redirect_status_code(self, data, **kwargs):
+        redirect_status_code_dict = {
+            301: "permanent",
+            302: "temporary",
+        }
+        data["redirect_status_code"] = redirect_status_code_dict[
+            data["redirect_status_code"]
+        ]
+
+        if not data['redirect_enable']:
+            data['redirect_status_code'] = None
+
+        return data
+
     class Meta:
         ordered = True
 
